==> cocoon-2.1.11-src.tar.gz: cocoon-2.1.11/src/blocks/forms/java/org/apache/cocoon/forms/formmodel/RepeaterFilterFieldDefinitionBuilder.java <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.apache.cocoon.forms.formmodel;

import org.apache.cocoon.forms.util.DomHelper;
import org.w3c.dom.Element;

public class RepeaterFilterFieldDefinitionBuilder extends
		FieldDefinitionBuilder {

	public WidgetDefinition buildWidgetDefinition(Element widgetElement) throws Exception {
        RepeaterFilterFieldDefinition definition = new RepeaterFilterFieldDefinition();
        setupDefinition(widgetElement, definition);
        definition.makeImmutable();
        return definition;
	}

	protected void setupDefinition(Element widgetElement,RepeaterFilterFieldDefinition definition) throws Exception {
		super.setupDefinition(widgetElement, definition);
		definition.setRepeaterName(DomHelper.getAttribute(widgetElement, "repeater"));
		definition.setField(DomHelper.getAttribute(widgetElement, "field"));
	}

}

==> cocoon-2.1.13-src.tar.gz: cocoon-2.1.13/src/blocks/forms/java/org/apache/cocoon/forms/formmodel/RepeaterFilterFieldDefinitionBuilder.java <==
/*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements.  See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.apache.cocoon.forms.formmodel;

import org.apache.cocoon.forms.util.DomHelper;
import org.w3c.dom.Element;

/**
 * @version $Id: RepeaterFilterFieldDefinitionBuilder.java 615293 2008-01-25 18:12:43Z vgritsenko $
 */
public class RepeaterFilterFieldDefinitionBuilder extends FieldDefinitionBuilder {

	public WidgetDefinition buildWidgetDefinition(Element widgetElement, WidgetDefinitionBuilderContext context)
    throws Exception {
        RepeaterFilterFieldDefinition definition = new RepeaterFilterFieldDefinition();
        setupDefinition(widgetElement, definition, context);

        definition.makeImmutable();
        return definition;
	}

	protected void setupDefinition(Element widgetElement,RepeaterFilterFieldDefinition definition, WidgetDefinitionBuilderContext context)
    throws Exception {
		super.setupDefinition(widgetElement, definition, context);

        definition.setRepeaterName(DomHelper.getAttribute(widgetElement, "repeater"));
		definition.setField(DomHelper.getAttribute(widgetElement, "field"));
	}
}
